@@ -73,13 +73,29 @@ class Adumo:
         acs_payload = response_dict.get("acsPayload")
         acs_url = response_dict.get("acsUrl")
         three_d_secure_enrolled = response_dict.get("threeDSecureAuthRequired")
+        error_code = response_dict.get("errorCode")
+
+        if error_code:
+            error_message = response_dict.get("message")
+            logger.error(
+                f"[Creditcard] Authenticate 3ds error: {error_code=} {error_message=}"
+            )
+            return {
+                "status": FAILED,
+                "transaction_id": transaction_id,
+                "message": f"3d Secure error {error_message=}",
+            }
 
         if not three_d_secure_enrolled:
+            logger.error(
+                f"[Creditcard] Card not enrolled in 3ds"
+            )
             return {
                 "status": FAILED,
                 "transaction_id": transaction_id,
                 "message": "Card not Enrolled in 3ds, cannot process payment",
             }
+
         md = self.encode_md(transaction_id, amount, card.security_code)
 
         return {
@@ -90,11 +106,11 @@ class Adumo:
             "acs_url": acs_url,
         }
 
-    def authorise_and_settle_payment(self, pareq, md):
+    def authorise_and_settle_payment(self, pares, md):
         transaction_id, amount, cvv = self.decode_md(md)
 
         try:
-            self._authenticate(pareq, md)
+            self._authenticate(pares, md)
         except CreditCardProcessor3dsFailure():
             return {"status": FAILED, "transaction_id": transaction_id}
 
@@ -104,9 +120,9 @@ class Adumo:
 
         return result
 
-    def _authenticate(self, pareq: str, md: str):
+    def _authenticate(self, pares: str, md: str):
         url = f"{API_URL}product/authentication/v1/tds/authenticate/"
-        request = {"md": md, "payload": pareq}
+        request = {"md": md, "payload": pares}
         result = httpx.post(url, json=request, headers=self.headers)
 
         response_dict = self._process_response(result)
@@ -157,14 +173,6 @@ class Adumo:
     def _process_response(response):
         response_dict = response.json()
         status_code = response_dict.get("statusCode")
-        error_code = response_dict.get("errorCode")
-
-        if error_code:
-            error_message = response_dict.get("message")
-            logger.error(
-                f"[Creditcard] Authenticate 3ds error: {error_code=} {error_message=}"
-            )
-            raise CreditCardProcessor3dsFailure(error_code, error_message)
 
         if status_code and status_code != 200:
             status_message = response_dict.get("statusMessage")
